//------------------------------------------------------------------------------
//
//  npfile.h
//
//  ANTz application based on NPE
//
//  Created by Shane Saxon on 3/6/11.
//  Copyright Saxon Digital 2010-2011. All rights reserved.
//
//------------------------------------------------------------------------------
#ifndef NPFILE_H_
#define NPFILE_H_


#include <stdio.h>
#include "../npdata.h"

#define kNPfileMax 4096

//------------------------------------------------------------------------------
void npInitFile (void* dataRef);	// init the file io system
void npCloseFile (void* dataRef);	// for init and shutdown, not closing a file

// these functions wrap the standard C file methods on Linux, MSW and OSX
// opens or creates the file in the specified mode "rb+" read/write binary..
FILE* npFileOpen (const char* fileName, const char* mode, void* dataRef);
FILE* npFileNew (const char* fileName, const char* mode, void* dataRef);
FILE* npFileDialog (const char* fileName, int dialogType, void* dataRef);

// if not saved then opens SaveAs dialog before reseting app
int npFileClose (FILE* file, void* dataRef);

// wrappers for fread(), fwrite() and rewind()
//void npFileRead (void* writeBuffer, int wordSize, int size, void* dataRef);
int npFileRead (void* readBuffer, int elementSize, int elementCount, 
				 FILE* file, void* dataRef);
int npFileWrite (const void* str, int wordSize, int size, FILE* file, void* dataRef);

void npFileRewind (FILE* file);
int npFileSeek (FILE* file, long offSet, int origin);
long npFileTell (FILE* file);

// 
void npSave (FILE* file, void* dataRef);
void npSaveAs (int size, void* dataRef);

void npImport (const char* fileName, void* dataRef);
void npExport (int size, void* dataRef);

// file and directory management

void npGetOpenFilePath (char* buffer, int* size, void* dataRef);
void npGetCWD (char* buffer, int* size);			//get Current Working Directory

void npListDir (int size, void* dataRef);

void npMakeDir (int size, void* dataRef);
void npDelDir (int size, void* dataRef);

void npGetFileAttrib (int size, void* dataRef);
void npSetFileAttrib (int size, void* dataRef);

void npTestFile (void* fileName, int wordSize, int size, void* dataRef);


#endif